import axios from 'axios'
import { getToken } from '../api/auth'
import { Notification, MessageBox, ElMessage  } from 'element-plus'
import errorCode from '@/api/errorCode'
import store from '../store'
const baseUrl = require('../utils/baseUrl.js')

// 创建一个 axios 实例
// const token = getToken() ? getToken() : window.sessionStorage.getItem('token')
const service = axios.create({
    // baseURL: process.env.VUE_APP_BASE_API, // 所有的请求地址前缀部分
    baseURL: process.env.NODE_ENV === "production" ? baseUrl.ROOT : baseUrl.ROOT, // 所有的请求地址前缀部分
    timeout: 60000, // 请求超时时间毫秒
    // withCredentials: true, // 异步请求携带cookie
    headers: {
        // 设置后端需要的传参类型
        'Content-Type': 'application/json;charset=utf-8',
        'X-Requested-With': 'XMLHttpRequest',
    },
})

// 添加请求拦截器
service.interceptors.request.use(
    function (config) {
        config.headers['Blade-Auth'] = window.localStorage.getItem('token')
        config.headers.code = window.localStorage.getItem('code')
        // 在发送请求设置cancel token
        config.cancelToken = new axios.CancelToken(cancel =>{
            store.commit('setAxiosArr', {cancelToken: cancel})
        })
        return config
    },
    function (error) {
        // 对请求错误做些什么
        console.log(error)
        return Promise.reject(error)
    }
)

// 添加响应拦截器
service.interceptors.response.use(
    function (res) {
        // console.log(response)
        // // 2xx 范围内的状态码都会触发该函数。
        // // 对响应数据做点什么
        // // dataAxios 是 axios 返回数据中的 data
        // const dataAxios = response.data
        // // 这个状态码是和后端约定的
        // const code = dataAxios.reset
        // return dataAxios

        // 未设置状态码则默认成功状态
        const code = res.data.code || 200;
        // 获取错误信息
        const msg = errorCode[code] || res.data.msg || res.data.message || errorCode['default']
        if (code === 401) {
            MessageBox.confirm('登录状态已过期，您可以继续留在该页面，或者重新登录', '系统提示', {
                confirmButtonText: '重新登录',
                cancelButtonText: '取消',
                type: 'warning'
                }
            ).then(() => {
                this.$route.replace({path: '/login'})
            })
        } else if (code === 402) {
            MessageBox.confirm(msg, '系统提示', {
                confirmButtonText: '重新登录',
                cancelButtonText: '取消',
                type: 'warning'
            }).then(() => {
            })
        } else if (code === 500) {
            ElMessage ({
                message: msg,
                type: 'error'
            })
            return Promise.reject(new Error(msg))
        } else if (code !== 200) {
            Notification.error({
                title: msg
            })
            return Promise.reject('error')
        } else {
            return res.data
        }
    },
    function (error) {
        // // 超出 2xx 范围的状态码都会触发该函数。
        // // 对响应错误做点什么
        // console.log(error)
        // return Promise.reject(error)
        let { message } = error;
        if (message) {
            let code = message.substr(message.length - 3, message.length)
        if (message == "Network Error") {
            message = "后端接口连接异常";
        } else if (message.includes("timeout")) {
            message = "系统接口请求超时";
        } else if (message.includes("Request failed with status code")) {
            message = "系统接口" + message.substr(message.length - 3) + "异常";
        }
        if (code !== '401') {
            ElMessage ({
                message: message,
                type: 'error',
                duration: 5 * 1000
            })
        }
        if (code === '401') {
            let url = location.origin + '/#/login'
            window.open(url, '_self')
        }
            return Promise.reject(error)
        } else {
            return new Promise(() =>{})
        }
    }
)

export default service

